module Frozen
  module Site
    class Base
      attr_accessor :site_root_path

      def initialize
        @options = {}
      end

      def build_path
        File.join(site_root_path, "build")
      end

      def stylesheet_template_path
        File.join(site_root_path, "assets/stylesheets")
      end

      def javascript_template_path
        File.join(site_root_path, "assets/javascripts")
      end

      def view_template_path
        File.join(site_root_path, "views")
      end

      def layout_template_path
        File.join(site_root_path, "layouts")
      end

      def stylesheet_build_path
        File.join(build_path, "css")
      end

      def javascript_build_path
        File.join(build_path, "js")
      end

      def view_build_path
        site_root_path
      end

      def image_template_path
        File.join(site_root_path, 'assets/images')
      end

      def file_is_view?(file)
        file =~ /^views/
      end

      def file_is_layout?(file)
        file =~ /^layouts/
      end

      def file_is_stylesheet?(file)
        file =~ /^assets\/stylesheets/
      end

      def file_is_javascript?(file)
        file =~ /^assets\/javascripts/
      end

      def image_build_path
        File.join(build_path, 'images')
      end

      def files_in_path(path, ext)
        files = []
        if ext.is_a? String
          files = Dir.glob(File.join(path, "/**/*.#{ext}"))
        end
        if ext.is_a? Array
          ext.each do |e|
            files += Dir.glob(File.join(path, "/**/*.#{e}"))
          end
        end
        if files
          files.delete_if { |i| File.basename(i) =~ /^\_/ }
        end
        files
      end
    end
  end
end
