require 'frozen/site/base'
require 'colorize'

module Frozen
  module Site
    class LocalSite < Base

      def initialize(site_root_path)
        @site_root_path = File.expand_path(site_root_path)
        super()
      end

      def build
        build_stylesheets
        build_javascripts
        build_views
      end

      def stylesheet_file_paths
        @stylesheet_file_paths ||= files_in_path(
          stylesheet_template_path,
          "scss")
      end

      def stylesheets
        @stylesheets ||= stylesheet_file_paths.map {|file_path|
          engine = Frozen::Template::Stylesheet.new(
            load_path: stylesheet_template_path
          )
          engine.template_root_path = stylesheet_template_path
          engine.file_path = file_path
          engine
        }
      end


      def build_stylesheets
        stylesheets.each do |stylesheet|
          build_stylesheet(stylesheet)
        end
      end

      def build_stylesheet(stylesheet)
        if stylesheet.is_a? Frozen::Template::Stylesheet
          stylesheet.render_to_file(
            File.join(site_build_path,stylesheet.build_file_path)
          )
          puts "#{"[stylesheet]".green} #{stylesheet.build_file_path}"
        end
        if stylesheet.is_a? String
          engine = Frozen::Template::Stylesheet.new(
            load_path: stylesheet_template_path
          )
          engine.template_root_path = stylesheet_template_path
          engine.file_path = file_path
          engine.render_to_file(
            File.join(site_build_path,stylesheet.build_file_path)
          )
          puts "#{"[view]".green} #{engine.build_file_path}"
        end
      end
      def javascript_file_paths
        @javascript_file_paths ||= files_in_path(
          javascript_template_path,
          ["js", "coffee"])
      end

      def javascripts
        @javascripts ||= javascript_file_paths.map{ |file_path|
          engine = Frozen::Template::Javascript.new
          engine.template_root_path = javascript_template_path
          engine.file_path = file_path
          engine
        }
      end

      def build_javascript(javascript)
        if javascript.is_a? Frozen::Template::Javascript
          javascript.render_to_file(
            File.join(site_build_path,javascript.build_file_path)
          )
          puts "#{"[javascript]".green} #{javascript.build_file_path}"
        end
        if javascript.is_a? String
          engine = Frozen::Template::Javascript.new
          engine.template_root_path = javascript_template_path
          engine.file_path = file_path
          engine.render_to_file(
            File.join(site_build_path,engine.build_file_path)
          )
          puts "#{"[javascript]".green} #{engine.build_file_path}"
        end
      end

      def build_javascripts
        javascripts.each {|i| build_javascript(i)}
      end


      def view_file_paths
        @view_file_paths ||= files_in_path(view_template_path, "slim")
      end

      def views
          @views ||= view_file_paths.map{|file_path|
            engine = Frozen::Template::View.new
            engine.file_path = file_path
            engine.template_root_path = view_template_path
            engine.layout_path = layout_template_path
            engine
          }
      end

      def build_views
        views.each { |v| build_view(v) }
      end

      def build_view(view)
          view.render_to_file(
            File.join(site_build_path, view.build_file_path)
          )
          puts "#{"[view]".green} #{view.build_file_path}"
      end

      def site_build_path
        File.join(site_root_path, "build")
      end

    end
  end
end
